@@ -100,7 +100,9 @@
 
 ;;; Code:
 
+(require 'magit-git)
 (require 'magit-mode)
+(require 'magit-process)
 
 (require 'log-edit)
 (require 'ring)
@@ -192,12 +194,12 @@ The major mode configured here is turned on by the minor mode
 Also note that `git-commit-mode' (which see) is not a major-mode.")
 
 (defcustom git-commit-setup-hook
-  '(git-commit-ensure-comment-gap
-    git-commit-save-message
-    git-commit-setup-changelog-support
-    git-commit-turn-on-auto-fill
-    git-commit-propertize-diff
-    bug-reference-mode)
+  (list #'git-commit-ensure-comment-gap
+        #'git-commit-save-message
+        #'git-commit-setup-changelog-support
+        #'git-commit-turn-on-auto-fill
+        #'git-commit-propertize-diff
+        #'bug-reference-mode)
   "Hook run at the end of `git-commit-setup'."
   :group 'git-commit
   :type 'hook
@@ -243,7 +245,7 @@ commit, then the hook is not run at all."
   :type 'number)
 
 (defcustom git-commit-finish-query-functions
-  '(git-commit-check-style-conventions)
+  (list #'git-commit-check-style-conventions)
   "List of functions called to query before performing commit.
 
 The commit message buffer is current while the functions are
@@ -738,7 +740,7 @@ conventions are checked."
 
 (defun git-commit-prev-message (arg)
   "Cycle backward through message history, after saving current message.
-With a numeric prefix ARG, go back ARG comments."
+With a numeric prefix ARG, go back ARG messages."
   (interactive "*p")
   (let ((len (ring-length log-edit-comment-ring)))
     (if (<= len 0)
@@ -766,7 +768,7 @@ With a numeric prefix ARG, go back ARG comments."
 
 (defun git-commit-next-message (arg)
   "Cycle forward through message history, after saving current message.
-With a numeric prefix ARG, go forward ARG comments."
+With a numeric prefix ARG, go forward ARG messages."
   (interactive "*p")
   (git-commit-prev-message (- arg)))
 
