@@ -308,7 +308,7 @@ Then show the status buffer for the new repository."
         (concat "file://"
                 (magit-convert-filename-for-git
                  (read-directory-name "Clone repository: file://"))))
-    (?b "or [b]undle"
+    (?b "[b]undle"
         (magit-convert-filename-for-git
          (read-file-name "Clone from bundle: ")))))
 
