@@ -54,17 +54,17 @@
 ;;; Options
 
 (defcustom magit-mode-hook
-  '(magit-load-config-extensions)
+  (list #'magit-load-config-extensions)
   "Hook run when entering a mode derived from Magit mode."
   :package-version '(magit . "3.0.0")
   :group 'magit-modes
   :type 'hook
-  :options '(magit-load-config-extensions
-             bug-reference-mode))
+  :options (list #'magit-load-config-extensions
+                 #'bug-reference-mode))
 
 (defcustom magit-setup-buffer-hook
-  '(magit-maybe-save-repository-buffers
-    magit-set-buffer-margin)
+  (list #'magit-maybe-save-repository-buffers
+        'magit-set-buffer-margin) ; from magit-margin.el
   "Hook run by `magit-setup-buffer'.
 
 This is run right after displaying the buffer and right before
@@ -75,10 +75,11 @@ should be used instead of this one."
   :package-version '(magit . "2.3.0")
   :group 'magit-modes
   :type 'hook
-  :options '(magit-maybe-save-repository-buffers
-             magit-set-buffer-margin))
+  :options (list #'magit-maybe-save-repository-buffers
+                 'magit-set-buffer-margin))
 
-(defcustom magit-pre-refresh-hook '(magit-maybe-save-repository-buffers)
+(defcustom magit-pre-refresh-hook
+  (list #'magit-maybe-save-repository-buffers)
   "Hook run before refreshing in `magit-refresh'.
 
 This hook, or `magit-post-refresh-hook', should be used
@@ -90,9 +91,10 @@ inside your function."
   :package-version '(magit . "2.4.0")
   :group 'magit-refresh
   :type 'hook
-  :options '(magit-maybe-save-repository-buffers))
+  :options (list #'magit-maybe-save-repository-buffers))
 
 (defcustom magit-post-refresh-hook
+  ;; Do not function-quote to avoid circular dependencies.
   '(magit-auto-revert-buffers
     magit-run-post-commit-hook
     magit-run-post-stage-hook
@@ -121,36 +123,37 @@ All Magit buffers (buffers whose major-modes derive from
 which in turn uses the function specified here."
   :package-version '(magit . "2.3.0")
   :group 'magit-buffers
-  :type '(radio (function-item magit-display-buffer-traditional)
-                (function-item magit-display-buffer-same-window-except-diff-v1)
-                (function-item magit-display-buffer-fullframe-status-v1)
-                (function-item magit-display-buffer-fullframe-status-topleft-v1)
-                (function-item magit-display-buffer-fullcolumn-most-v1)
-                (function-item display-buffer)
+  :type `(radio (function-item ,#'magit-display-buffer-traditional)
+                (function-item ,#'magit-display-buffer-same-window-except-diff-v1)
+                (function-item ,#'magit-display-buffer-fullframe-status-v1)
+                (function-item ,#'magit-display-buffer-fullframe-status-topleft-v1)
+                (function-item ,#'magit-display-buffer-fullcolumn-most-v1)
+                (function-item ,#'display-buffer)
                 (function :tag "Function")))
 
-(defcustom magit-pre-display-buffer-hook '(magit-save-window-configuration)
+(defcustom magit-pre-display-buffer-hook
+  (list #'magit-save-window-configuration)
   "Hook run by `magit-display-buffer' before displaying the buffer."
   :package-version '(magit . "2.3.0")
   :group 'magit-buffers
   :type 'hook
   :get #'magit-hook-custom-get
-  :options '(magit-save-window-configuration))
+  :options (list #'magit-save-window-configuration))
 
-(defcustom magit-post-display-buffer-hook '(magit-maybe-set-dedicated)
+(defcustom magit-post-display-buffer-hook (list #'magit-maybe-set-dedicated)
   "Hook run by `magit-display-buffer' after displaying the buffer."
   :package-version '(magit . "2.3.0")
   :group 'magit-buffers
   :type 'hook
   :get #'magit-hook-custom-get
-  :options '(magit-maybe-set-dedicated))
+  :options (list #'magit-maybe-set-dedicated))
 
 (defcustom magit-generate-buffer-name-function
   #'magit-generate-buffer-name-default-function
   "The function used to generate the name for a Magit buffer."
   :package-version '(magit . "2.3.0")
   :group 'magit-buffers
-  :type '(radio (function-item magit-generate-buffer-name-default-function)
+  :type `(radio (function-item ,#'magit-generate-buffer-name-default-function)
                 (function :tag "Function")))
 
 (defcustom magit-buffer-name-format "%x%M%v: %t%x"
@@ -199,9 +202,9 @@ support additional %-sequences."
   "The function used to bury or kill the current Magit buffer."
   :package-version '(magit . "3.2.0")
   :group 'magit-buffers
-  :type '(radio (function-item quit-window)
-                (function-item magit-mode-quit-window)
-                (function-item magit-restore-window-configuration)
+  :type `(radio (function-item ,#'quit-window)
+                (function-item ,#'magit-mode-quit-window)
+                (function-item ,#'magit-restore-window-configuration)
                 (function :tag "Function")))
 
 (defcustom magit-prefix-use-buffer-arguments 'selected
@@ -269,7 +272,8 @@ and Buffer Variables'."
           (const :tag "use args from buffer if it is current" current)
           (const :tag "never use args from buffer" never)))
 
-(defcustom magit-region-highlight-hook '(magit-diff-update-hunk-region)
+(defcustom magit-region-highlight-hook
+  '(magit-diff-update-hunk-region) ; from magit-diff.el
   "Functions used to highlight the region.
 
 Each function is run with the current section as only argument
@@ -830,10 +834,10 @@ into thinking a buffer belongs to a repo that it doesn't.")
 
 (defun magit-mode-get-buffers ()
   (let ((topdir (magit-toplevel)))
-    (--filter (with-current-buffer it
-                (and (derived-mode-p 'magit-mode)
-                     (equal magit--default-directory topdir)))
-              (buffer-list))))
+    (seq-filter (##with-current-buffer %
+                  (and (derived-mode-p 'magit-mode)
+                       (equal magit--default-directory topdir)))
+                (buffer-list))))
 
 (defvar-local magit-buffer-locked-p nil)
 (put 'magit-buffer-locked-p 'permanent-local t)
@@ -979,14 +983,14 @@ current buffer is the last remaining Magit buffer that was
 ever displayed in the selected window, then delete that
 window."
   (if (or (one-window-p)
-          (--first (let ((buffer (car it)))
-                     (and (not (eq buffer (current-buffer)))
-                          (buffer-live-p buffer)
-                          (or (not (window-parameter nil 'magit-dedicated))
-                              (with-current-buffer buffer
-                                (derived-mode-p 'magit-mode
-                                                'magit-process-mode)))))
-                   (window-prev-buffers)))
+          (seq-find (pcase-lambda (`(,buffer))
+                      (and (not (eq buffer (current-buffer)))
+                           (buffer-live-p buffer)
+                           (or (not (window-parameter nil 'magit-dedicated))
+                               (with-current-buffer buffer
+                                 (derived-mode-p 'magit-mode
+                                                 'magit-process-mode)))))
+                    (window-prev-buffers)))
       (quit-window kill-buffer)
     (let ((window (selected-window)))
       (quit-window kill-buffer)
@@ -1179,10 +1183,6 @@ if you so desire."
                  (not (equal msg (current-message))))
         (message "%s" msg)))))
 
-(add-hook 'magit-pre-refresh-hook #'magit-maybe-save-repository-buffers)
-(add-hook 'magit-pre-call-git-hook #'magit-maybe-save-repository-buffers)
-(add-hook 'magit-pre-start-git-hook #'magit-maybe-save-repository-buffers)
-
 (defvar-local magit-inhibit-refresh-save nil)
 
 (defun magit-save-repository-buffers (&optional arg)
@@ -1329,6 +1329,7 @@ Later, when the buffer is buried, it may be restored by
   'help-echo (purecopy "mouse-2, RET: go back to next history entry"))
 
 (defvar magit-xref-modes
+  ;; Do not function-quote to avoid circular dependencies.
   '(magit-log-mode
     magit-reflog-mode
     magit-diff-mode
@@ -1499,6 +1500,22 @@ The additional output can be found in the *Messages* buffer."
                   (message "  %-50s %f" fn (benchmark-elapse (funcall fn))))))))
    ((run-hooks hook))))
 
+(defun magit-file-region-line-numbers ()
+  "Return the bounds of the region as line numbers.
+The returned value has the form (BEGINNING-LINE END-LINE).  If
+the region end at the beginning of a line, do not include that
+line.  Avoid including the line after the end of the file."
+  (and (or magit-buffer-file-name buffer-file-name)
+       (region-active-p)
+       (not (= (region-beginning) (region-end) (1+ (buffer-size))))
+       (let ((beg (region-beginning))
+             (end (min (region-end) (buffer-size))))
+         (list (line-number-at-pos beg t)
+               (line-number-at-pos (if (= (magit--bol-position end) end)
+                                       (max beg (1- end))
+                                     end)
+                                   t)))))
+
 ;;; _
 (provide 'magit-mode)
 ;;; magit-mode.el ends here
